<?php $TRANSLATIONS = array(
"Access granted" => "Accès autorisé",
"Error configuring Dropbox storage" => "Erreur lors de la configuration du support de stockage Dropbox",
"Grant access" => "Autoriser l'accès",
"Please provide a valid Dropbox app key and secret." => "Veuillez fournir une clé d'application (app key) ainsi qu'un mot de passe valides.",
"Error configuring Google Drive storage" => "Erreur lors de la configuration du support de stockage Google Drive",
"<b>Warning:</b> \"smbclient\" is not installed. Mounting of CIFS/SMB shares is not possible. Please ask your system administrator to install it." => "<b>Attention : </b> \"smbclient\" n'est pas installé. Le montage des partages CIFS/SMB n'est pas disponible. Contactez votre administrateur système pour l'installer.",
"<b>Warning:</b> The FTP support in PHP is not enabled or installed. Mounting of FTP shares is not possible. Please ask your system administrator to install it." => "<b>Attention : </b> Le support FTP de PHP n'est pas activé ou installé. Le montage des partages FTP n'est pas disponible. Contactez votre administrateur système pour l'installer.",
"External Storage" => "Stockage externe",
"Folder name" => "Nom du dossier",
"Configuration" => "Configuration",
"Options" => "Options",
"Applicable" => "Disponible",
"None set" => "Aucun spécifié",
"All Users" => "Tous les utilisateurs",
"Groups" => "Groupes",
"Users" => "Utilisateurs",
"Delete" => "Supprimer",
"Enable User External Storage" => "Activer le stockage externe pour les utilisateurs",
"Allow users to mount their own external storage" => "Autoriser les utilisateurs à monter leur propre stockage externe",
"SSL root certificates" => "Certificats racine SSL",
"Import Root Certificate" => "Importer un certificat racine"
);
